
import { CreditCard, LineChart, Lock, PieChart, Zap } from 'lucide-react';
import { cn } from '@/lib/utils';
import { useState } from 'react';
import { Draggable, ItemTypes } from './ui/draggable';
import { DndProvider } from './ui/dnd-provider';

const Features = () => {
  const initialFeatures = [
    {
      icon: <CreditCard className="w-6 h-6" />,
      title: "Advanced Risk Scoring",
      description: "Sophisticated algorithms analyze multiple data points to generate accurate default risk scores on a 0-100 scale.",
      color: "bg-brand-red/10"
    },
    {
      icon: <LineChart className="w-6 h-6" />,
      title: "Trend Analysis",
      description: "Track payment behaviors over time to identify patterns and predict future client performance.",
      color: "bg-brand-orange/10"
    },
    {
      icon: <Lock className="w-6 h-6" />,
      title: "Secure Data Processing",
      description: "Bank-grade encryption and security protocols protect sensitive financial information.",
      color: "bg-secondary/10"
    },
    {
      icon: <PieChart className="w-6 h-6" />,
      title: "Multi-Factor Evaluation",
      description: "Comprehensive assessment considering personal, financial, geographic, and behavioral factors.",
      color: "bg-brand-orange/10"
    },
    {
      icon: <Zap className="w-6 h-6" />,
      title: "Real-Time Processing",
      description: "Get instant risk assessments and predictions for immediate decision-making.",
      color: "bg-brand-red/10"
    }
  ];

  const [features, setFeatures] = useState(initialFeatures);

  const moveFeature = (dragIndex: number, hoverIndex: number) => {
    const draggedFeature = features[dragIndex];
    const newFeatures = [...features];
    newFeatures.splice(dragIndex, 1);
    newFeatures.splice(hoverIndex, 0, draggedFeature);
    setFeatures(newFeatures);
  };

  return (
    <DndProvider>
      <section id="features" className="section-container">
        <div className="text-center max-w-3xl mx-auto mb-16">
          <h2 className="heading-lg mb-6 animate-fade-up">Comprehensive Risk Assessment Features</h2>
          <p className="subtitle animate-fade-up" style={{ animationDelay: '0.1s' }}>
            Our platform combines cutting-edge AI with intuitive design to deliver actionable insights for your financial decisions.
          </p>
          <p className="text-sm mt-4 text-muted-foreground">Drag and drop features to reorder them</p>
        </div>

        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
          {features.map((feature, index) => (
            <Draggable 
              key={index} 
              id={index} 
              index={index} 
              type={ItemTypes.FEATURE}
              moveItem={moveFeature}
              className="cursor-move"
            >
              <div 
                className="glass-panel p-6 card-hover animate-fade-up relative"
                style={{ animationDelay: `${0.1 + index * 0.1}s` }}
              >
                <div className="absolute top-2 right-2 text-xs text-muted-foreground">
                  Drag to reposition
                </div>
                <div className={cn("p-3 rounded-xl w-12 h-12 flex items-center justify-center mb-4", feature.color)}>
                  {feature.icon}
                </div>
                <h3 className="heading-sm mb-2">{feature.title}</h3>
                <p className="text-muted-foreground">{feature.description}</p>
              </div>
            </Draggable>
          ))}
        </div>
      </section>
    </DndProvider>
  );
};

export default Features;
